==> haskell-enclosed-exceptions-1.0.2-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-enclosed-exceptions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: enclosed-exceptions
version: 1.0.2
id: enclosed-exceptions-1.0.2-LMjQACvzJ8YmslYTB8HhY
key: enclosed-exceptions-1.0.2-LMjQACvzJ8YmslYTB8HhY
license: MIT
maintainer: jmacristovao@gmail.com, michael@snoyman.com
homepage: https://github.com/jcristovao/enclosed-exceptions
synopsis: Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>
category: Control
author: Michael Snoyman, João Cristóvão
exposed: True
exposed-modules:
    Control.Exception.Enclosed
abi: 34b2ced1bca2a65b464d3b6f2524bf00
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/enclosed-exceptions-1.0.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/enclosed-exceptions-1.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/enclosed-exceptions-1.0.2
hs-libraries: HSenclosed-exceptions-1.0.2-LMjQACvzJ8YmslYTB8HhY
depends:
    base-4.9.0.0 deepseq-1.4.2.0
    lifted-base-0.2.3.8-49pRtI70Gt75UpVUvp7oxA
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock
haddock-html: /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-enclosed-exceptions-1.0.2-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-enclosed-exceptions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: enclosed-exceptions
version: 1.0.2
id: enclosed-exceptions-1.0.2-6pg8D5KASpCWGNo6DMJ9B
key: enclosed-exceptions-1.0.2-6pg8D5KASpCWGNo6DMJ9B
license: MIT
maintainer: jmacristovao@gmail.com, michael@snoyman.com
homepage: https://github.com/jcristovao/enclosed-exceptions
synopsis: Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>
category: Control
author: Michael Snoyman, João Cristóvão
exposed: True
exposed-modules:
    Control.Exception.Enclosed
abi: a583438a68accc2d54640ca322c223ef
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/enclosed-exceptions-1.0.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/enclosed-exceptions-1.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/enclosed-exceptions-1.0.2
hs-libraries: HSenclosed-exceptions-1.0.2-6pg8D5KASpCWGNo6DMJ9B
depends:
    base-4.9.0.0 deepseq-1.4.2.0
    lifted-base-0.2.3.10-GN8bGJb6NKpLjv5n9gQH0C
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock
haddock-html: /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
